==> haskell-http3-0.0.2-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.2
visibility:           public
id:                   http3-0.0.2-2LJFvxGamHR7nZffYgeyOl
key:                  http3-0.0.2-2LJFvxGamHR7nZffYgeyOl
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  7a0b3cb1a0b245c7314d9ee3468c3021
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.2-2LJFvxGamHR7nZffYgeyOl
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV containers-0.6.7
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    http2-4.1.4-5LeCZXDPotzAkQoVZ3t0PG
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.9-5QOAALHgGcfBXRUNE1V7t8
    sockaddr-0.0.1-BzzprgTk5dMK8zPF9Vf7EH stm-2.5.1.0
    time-manager-0.0.1-6wvqP4ScA4GJS6gCZ4Wv50
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http3-0.0.3-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.3
visibility:           public
id:                   http3-0.0.3-7CwyyEy11Z71QNrFS0Frr
key:                  http3-0.0.3-7CwyyEy11Z71QNrFS0Frr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  5e4a96cfa517151db43989c71df8ec5f
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.3-7CwyyEy11Z71QNrFS0Frr
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-IiC4W3ne2FhKO4v0Ko50kd containers-0.6.7
    http-types-0.12.4-GvCYNDYAmXh2LOy70F8sjw
    http2-4.1.4-LQNCN1ufUhNJkM66qx86IF
    network-3.1.4.0-FVkzt15CfOKCnNYpElqt5j
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.11-6QdQerXKhgj6uKE9K0OsOJ
    sockaddr-0.0.1-5cClMSJwXQ0KSX5DqxMZUn stm-2.5.1.0
    time-manager-0.0.1-Byhua93fhRI4CXpCuwdBTt
    unliftio-0.2.25.1-B1T4fU5SOAMD3xDfl4gy9D

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
